@@ -1,7 +1,9 @@
+import numpy as np
 from abc import ABC, abstractmethod
 import json
 from typing import Union, List
 
+import pandas as pd
 import sqlalchemy as sql
 from sqlalchemy import ForeignKey
 from sqlalchemy.ext.compiler import compiles
@@ -250,11 +252,20 @@ class PrimaryDataTable(Table):
     def from_cdes(
         cls, schema: Schema, cdes: List[CommonDataElement]
     ) -> "PrimaryDataTable":
-        columns = [sql.Column(cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]], quote=True) for cde in cdes]
+        columns = [
+            sql.Column(
+                cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]], quote=True
+            )
+            for cde in cdes
+        ]
         columns.insert(
             0,
             sql.Column(
-                "row_id", SQLTYPES.INTEGER, primary_key=True, autoincrement=True, quote=True
+                "row_id",
+                SQLTYPES.INTEGER,
+                primary_key=True,
+                autoincrement=True,
+                quote=True,
             ),
         )
         table = sql.Table(
@@ -272,14 +283,12 @@ class PrimaryDataTable(Table):
             "primary_data", schema.schema, autoload_with=db.get_executor()
         )
         new_table = cls()
-        table.columns = [sql.Column(column.name, quote=True) for column in list(table.columns)]
+        table.columns = [
+            sql.Column(column.name, quote=True) for column in list(table.columns)
+        ]
         new_table.set_table(table)
         return new_table
 
-    def insert_dataset(self, dataset, db):
-        values = dataset.to_dict()
-        self.insert_values(values, db)
-
     def remove_dataset(self, dataset_name, schema_full_name, db):
         delete = sql.text(
             f'DELETE FROM "{schema_full_name}"."primary_data" '
@@ -324,3 +333,13 @@ class MetadataTable(Table):
             f'INSERT INTO "{self.schema}".{METADATA_TABLE} VALUES(:code, :metadata)'
         )
         db.execute(query, values)
+
+    def get_dataset_enums(self):
+        return json.loads(self.table["dataset"].metadata)["enumerations"]
+
+    def get_pandas_dtype_per_column(self):
+        mapping = {"text": str, "int": pd.Int64Dtype(), "real": np.float64}
+        return {
+            code: mapping.get(json.loads(cde.metadata)["sql_type"].lower())
+            for code, cde in self.table.items()
+        }
